# tmodelviz

`tmodelviz` is a Python package for simulating and visualizing biochemical models using Tellurium in a jupyter notebook.

## Features
- Load and simulate SBML and antimony models.
- Calculate rolling averages and fluxes.
- Interactive visualizations using Matplotlib and ipywidgets.

## Installation

```bash
pip install tmodelviz
